@@ -30,8 +30,8 @@ def setup_local_test_sqlite_file(
 
 def setup_local_test_postgres():
     process = run(
-        "docker run --name pgtest -e POSTGRES_PASSWORD=pwd -e POSTGRES_DB=pgtest -d -p"
-        " 5432:5432 postgres",  # noqa
+        "docker run --name pgtest -e POSTGRES_PASSWORD=pwd"
+        " -e POSTGRES_DB=pgtest -d -p 5432:5432 postgres",  # noqa
         shell=True,
     )
     if process.returncode == 0:
