@@ -1,12 +1,8 @@
+import os
 from typing import Union
 
 from ._settings_instance import InstanceSettings
-from ._settings_load import (
-    load_instance_settings,
-    load_instance_settings_from_store,
-    load_or_create_user_settings,
-)
-from ._settings_store import InstanceSettingsStore
+from ._settings_load import load_instance_settings, load_or_create_user_settings
 from ._settings_user import UserSettings
 
 
@@ -30,30 +26,33 @@ class settings:
     _user_settings: Union[UserSettings, None] = None
     _instance_settings: Union[InstanceSettings, None] = None
 
+    _user_settings_env: Union[str, None] = None
+    _instance_settings_env: Union[str, None] = None
+
     @classproperty
     def user(cls) -> UserSettings:
         """User-related settings."""
-        if cls._user_settings is None:
+        if (
+            cls._user_settings is None
+            or cls._user_settings_env != get_env_name()  # noqa
+        ):
             cls._user_settings = load_or_create_user_settings()
-            if cls._user_settings.id is None:
+            cls._user_settings_env = get_env_name()
+            if cls._user_settings and cls._user_settings.id is None:
                 raise RuntimeError("Need to login, first: lndb login <email>.")
         return cls._user_settings  # type: ignore
 
     @classproperty
     def instance(cls) -> InstanceSettings:
         """Instance-related settings."""
-        if cls._instance_settings is None:
+        if (
+            cls._instance_settings is None
+            or cls._instance_settings_env != get_env_name()  # noqa
+        ):
             cls._instance_settings = load_instance_settings()
+            cls._instance_settings_env = get_env_name()
         return cls._instance_settings  # type: ignore
 
-    @staticmethod
-    def _instance(settings_store: InstanceSettingsStore = None) -> InstanceSettings:
-        """Instance-related settings optionally based on parameter."""
-        if settings_store:
-            instance_settings = load_instance_settings_from_store(settings_store)
-            return instance_settings
-        return settings.instance
-
     @classproperty
     def _instance_exists(cls):
         try:
@@ -61,3 +60,10 @@ class settings:
             return True
         except RuntimeError:
             return False
+
+
+def get_env_name():
+    if "LAMIN_ENV" in os.environ:
+        return os.environ["LAMIN_ENV"]
+    else:
+        return "prod"
